/*
FreeIMU.h - Interface a FreeIMU device with Arduino
Copyright (C) 2011 Fabio Varesano <fabio at varesano dot net>


This program is free software: you can redistribute it and/or modify
it under the terms of the version 3 GNU General Public License as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <Wire.h>
#include "WProgram.h"
//#include "ADXL345.h"
//#include "HMC5843.h"
#include "ITG3200.h"


#ifndef FreeIMU1_h
#define FreeIMU1_h

// default I2C 7-bit addresses of the sensors
//#define FIMU_ADXL345_DEF_ADDR 0x53 // SDO connected to GND
#define FIMU_ITG3200_DEF_ADDR 0x69 // AD0 connected to VCC
//#define FIMU_HMC5843_DEF_ADDR 0x1E // this is fixed

// ITG3200 constants
#define FIMU_ITG3200_SMPLRT_DIV 0x15
#define FIMU_ITG3200_DLPF_FS 0x16
#define FIMU_ITG3200_INT_CFG 0x17
#define FIMU_ITG3200_PWR_MGM 0x3E

class FreeIMU
{
  public:
    FreeIMU();
    void init();
    void init(int gyro_addr);
    void getRawValues(int * raw_values);
    void getValues(float * values);
    void getQ(float * q);
    void SetInitQ(float init_q0);
    float init_q0;

  private:
    int* raw_gyro;
    //HMC5843 magn;
    //ADXL345 acc;
    ITG3200 gyro;
    void AHRSupdate(float gx, float gy, float gz, float ax, float ay, float az, float mx, float my, float mz);
    float q0, q1, q2, q3; // quaternion elements representing the estimated orientation
    //float exInt, eyInt, ezInt;  // scaled integral error

};

#endif // FreeIMU1_h

